@@ -71,7 +71,8 @@ summary.sarlm <- function(object, correlation = FALSE, Nagelkerke=FALSE,
 		if (correlation) {
                         oresvar <- object$resvar
                         ctext <- "Correlation of coefficients"
-                        if (is.null(oresvar) || is.logical(oresvar)) {
+                        if (is.null(oresvar) || is.logical(oresvar) || 
+                            class(oresvar) == "try-error") {
                             oresvar <- object$fdHess
                             ctext <- ifelse(object$insert,
                                 "Approximate correlation of coefficients",
@@ -88,7 +89,8 @@ summary.sarlm <- function(object, correlation = FALSE, Nagelkerke=FALSE,
 		if (correlation) {
                         oresvar <- object$resvar
                         ctext <- "Correlation of coefficients"
-                        if (is.null(oresvar) || is.logical(oresvar)) {
+                        if (is.null(oresvar) || is.logical(oresvar) || 
+                            class(oresvar) == "try-error") {
                             oresvar <- object$fdHess
                             ctext <- "Approximate correlation of coefficients"
                         }
